@@ -9,13 +9,7 @@ import json
 from pyspark.sql import DataFrame
 import ipywidgets as widgets
 from ..services.clients import DatasetDocClient
-from ..jupyterextensions.authextension import AuthClient
-
-
-@staticmethod
-def default_doc_template_provider():
-    doc_template_client = DatasetDocClient(AuthClient.get_access_token, os.environ['DOC_TEMPLATE_URL'])
-    return doc_template_client.get_doc_template
+from ..jupyterextensions.authextension import AuthClient, AuthError
 
 
 @magics_class
@@ -55,15 +49,15 @@ class DaplaDocumentationMagics(Magics):
         Options:
 
             -f <filename>: specify a file where the documentation is stored
-            -n : Documentation is not stored to file
+            --nofile : Documentation is not stored to file
         """
 
-        opts, args = self.parse_options(line, 'nf:')
+        opts, args = self.parse_options(line, 'f:', 'nofile')
         if not args:
             raise UsageError('Missing variable name.')
 
         fname = opts.get('f')
-        use_file_storage = 'n' not in opts
+        use_file_storage = 'nofile' not in opts
 
         try:
             ds = self.shell.user_ns[args]
@@ -95,19 +89,23 @@ class DaplaDocumentationMagics(Magics):
 
         self.clear_output()
 
-        if use_file_storage:
-            file_exists = os.path.isfile(fname)
-            if file_exists:
-                with open(fname, 'r') as f:
-                    ds.doc = json.load(f)
+        try:
+            if use_file_storage:
+                file_exists = os.path.isfile(fname)
+                if file_exists:
+                    with open(fname, 'r') as f:
+                        ds.doc = json.load(f)
+                else:
+                    # Generate doc from template and prepare file
+                    ds.doc = self._doc_template_provider(ds.schema.json(), False)
+                    with open(fname, 'w', encoding="utf-8") as f:
+                        json.dump(ds.doc, f)
             else:
-                # Generate doc from template and prepare file
+                # Generate doc from template
                 ds.doc = self._doc_template_provider(ds.schema.json(), False)
-                with open(fname, 'w', encoding="utf-8") as f:
-                    json.dump(ds.doc, f)
-        else:
-            # Generate doc from template
-            ds.doc = self._doc_template_provider(ds.schema.json(), False)
+        except AuthError as err:
+            err.print_warning()
+            return
 
         variable_titles = []
         variable_forms = []
@@ -118,15 +116,18 @@ class DaplaDocumentationMagics(Magics):
             justify_content='space-between'
         )
 
+        def capitalize_with_camelcase(s):
+            return s[0].upper() + s[1:]
+
         for instanceVar in ds.doc['instanceVariables']:
-            variable_titles.append(instanceVar['name'].capitalize())
+            variable_titles.append(capitalize_with_camelcase(instanceVar['name']))
             form_items = []
 
             for key in instanceVar.keys():
                 if key == 'name':
                     continue
                 form_items.append(
-                    widgets.Box([widgets.Label(value=key.capitalize()), self.create_widget(instanceVar, key)],
+                    widgets.Box([widgets.Label(value=capitalize_with_camelcase(key)), self.create_widget(instanceVar, key)],
                                 layout=form_item_layout))
 
             variable_forms.append(widgets.Box(form_items, layout=widgets.Layout(
@@ -144,6 +145,8 @@ class DaplaDocumentationMagics(Magics):
         dataset_doc = widgets.Box([
             widgets.Box([widgets.Label(value='Name'), self.create_widget(ds.doc, 'name')], layout=form_item_layout),
             widgets.Box([widgets.Label(value='Description'), self.create_widget(ds.doc, 'description')],
+                        layout=form_item_layout),
+            widgets.Box([widgets.Label(value='UnitType'), self.create_widget(ds.doc, 'unitType')],
                         layout=form_item_layout)
             ], layout=widgets.Layout(
                 display='flex',
@@ -154,7 +157,7 @@ class DaplaDocumentationMagics(Magics):
         )
 
         display_objs = (widgets.HTML("<b>Dataset metadata</b>"), dataset_doc,
-                          widgets.HTML("<b>Instance variables</b>"), accordion)
+                        widgets.HTML("<b>Instance variables</b>"), accordion)
 
         def on_button_clicked(b):
             with open(fname, 'w', encoding="utf-8") as f:
@@ -178,7 +181,8 @@ class DaplaDocumentationMagics(Magics):
         elif isinstance(binding[key], dict) and binding[key].__contains__('candidates'):
             return self.create_candidate_selector(binding, key)
         else:
-            raise UsageError("Invalid type '{}'".format(key))
+            raise UsageError("Unable to create a widget for '{}' with value '{}'\n{}"
+                             .format(key, binding[key], json.dumps(binding, indent=2)))
 
     def create_text_input(self, binding, key):
         if key == 'description':
@@ -236,8 +240,9 @@ def load_ipython_extension(ipython):
     can be loaded via `%load_ext module.path` or be configured to be
     autoloaded by IPython at startup time.
     """
-    # This class must then be registered with a manually created instance,
+    doc_template_client = DatasetDocClient(AuthClient.get_access_token, os.environ['DOC_TEMPLATE_URL'])
+    # This class must be registered with a manually created instance,
     # since its constructor has different arguments from the default:
-    magics = DaplaDocumentationMagics(ipython, default_doc_template_provider())
+    magics = DaplaDocumentationMagics(ipython, doc_template_client.get_doc_template)
     ipython.register_magics(magics)
 
