@@ -45,6 +45,7 @@ class CatalogClient(AbstractClient):
                                  }, allow_redirects=False)
         handle_error_codes(response)
 
+
 class DataAccessClient(AbstractClient):
 
     def read_location(self, path):
@@ -124,6 +125,29 @@ class DatasetDocClient(AbstractClient):
         handle_error_codes(response)
         return response.json()
 
+    def get_lineage_template(self, output_schema, input_schema_map, use_simple=False):
+        request_url = self._base_url + '/lineage/template'
+
+        def mapper(x):
+            return (x[0], {
+                "schema": x[1]['schema'],
+                "schemaType": "SPARK",
+                "timestamp": x[1]['timestamp'],
+            })
+        request = {
+            "schema": output_schema['schema'],
+            "timestamp": output_schema['timestamp'],
+            "schemaType": "SPARK",
+            "simpleLineage": use_simple,
+            "dependencies": [dict(map(mapper, input_schema_map.items()))],
+        }
+        response = requests.post(request_url, json=request,
+                                 headers={
+                                     'Authorization': 'Bearer %s' % self._user_token_provider()
+                                 }, allow_redirects=False)
+        handle_error_codes(response)
+        return response.json()
+
 
 def handle_error_codes(response):
     if response.status_code == 401:
